# Cannot make hunspell to work

**URL:** <https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082>\
**Category:** Elasticsearch\
**Created:** [December 16, 2012, 11:25am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082 "2012-12-16T11:25:32Z")\
**Posts on this page:** 13\
**Page:** 1

<div class="post-metadata">

**Author:** ![muhamed\_alibegovic](https://avatars.discourse-cdn.com/v4/letter/m/ce7236/32.png) [@muhamed\_alibegovic](https://discuss.elastic.co/u/muhamed_alibegovic)\
**Post date:** [December 16, 2012, 11:25am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/1 "2012-12-16T11:25:32Z")

</div>

Hello,

I'm new to ES and also search engines. I would like to use hunspell for  
stemming the croatian language. This is my test setup and how I search

curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings": {"analysis":  
{"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
"hr\_HR","ignoreCase": "true"}}}}}'  
curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
'{"concepts": {"properties" : {"description" : { "type" : "string",  
"filter" : "hunspell\_hr" }}}}'  
curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name": "miki",  
"description": "mi bi smo voljeli da nađemo kuće u centru grada. Jer volimo  
da imamo vrt a i da su nam blizu objekti kulture."}'  
curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)' -d  
'{"query": {"query\_string": {"query": "description:kuća"}}'

Thanks!

--

---

<div class="post-metadata">

**Author:** ![muhamed\_alibegovic](https://avatars.discourse-cdn.com/v4/letter/m/ce7236/32.png) [@muhamed\_alibegovic](https://discuss.elastic.co/u/muhamed_alibegovic)\
**Post date:** [December 16, 2012, 7:39pm UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/2 "2012-12-16T19:39:44Z")

</div>

I forgot to mention that I can not make it work. Please can someone post me  
correct setup and usage.

Thanks

On Sunday, December 16, 2012 12:25:32 PM UTC+1, muhamed alibegovic wrote:

> Hello,
> 
> I'm new to ES and also search engines. I would like to use hunspell for  
> stemming the croatian language. This is my test setup and how I search
> 
> curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings": {"analysis":  
> {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> "hr\_HR","ignoreCase": "true"}}}}}'  
> curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> '{"concepts": {"properties" : {"description" : { "type" : "string",  
> "filter" : "hunspell\_hr" }}}}'  
> curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name":  
> "miki", "description": "mi bi smo voljeli da nađemo kuće u centru grada.  
> Jer volimo da imamo vrt a i da su nam blizu objekti kulture."}'  
> curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)' -d  
> '{"query": {"query\_string": {"query": "description:kuća"}}'
> 
> Thanks!

--

---

<div class="post-metadata">

**Author:** ![mvg](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/mvg/32/98890_2.png) [@mvg](https://discuss.elastic.co/u/mvg)\
**Post date:** [December 17, 2012, 8:41am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/3 "2012-12-17T08:41:46Z")

</div>

Hi Muhamed,

Did you install the Hunspell plugin  
([GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell))?  
What kind of error did you experience?

Martijn

On 16 December 2012 20:39, muhamed alibegovic  
[alibegovic.muhamed@gmail.com](mailto:alibegovic.muhamed@gmail.com) wrote:

> I forgot to mention that I can not make it work. Please can someone post me  
> correct setup and usage.
> 
> Thanks
> 
> On Sunday, December 16, 2012 12:25:32 PM UTC+1, muhamed alibegovic wrote:
> 
> > Hello,
> > 
> > I'm new to ES and also search engines. I would like to use hunspell for  
> > stemming the croatian language. This is my test setup and how I search
> > 
> > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings": {"analysis":  
> > {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> > "hr\_HR","ignoreCase": "true"}}}}}'  
> > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> > '{"concepts": {"properties" : {"description" : { "type" : "string", "filter"  
> > : "hunspell\_hr" }}}}'  
> > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name": "miki",  
> > "description": "mi bi smo voljeli da nađemo kuće u centru grada. Jer volimo  
> > da imamo vrt a i da su nam blizu objekti kulture."}'  
> > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)' -d  
> > '{"query": {"query\_string": {"query": "description:kuća"}}'
> > 
> > Thanks!
> 
> --

--  
Met vriendelijke groet,

Martijn van Groningen

--

---

<div class="post-metadata">

**Author:** ![Igor\_Motov](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/igor_motov/32/45193_2.png) [@Igor\_Motov](https://discuss.elastic.co/u/Igor_Motov)\
**Post date:** [December 17, 2012, 6:14pm UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/4 "2012-12-17T18:14:28Z")

</div>

Hi Muhamed,

After installing the plugin as Martijn suggested, make sure that you are  
using the filter from the plugin in an analyzer. Here is an  
example: [https://groups.google.com/d/topic/elasticsearch/LJVQctlocvg/discussion · GitHub](https://gist.github.com/4320493) . Don't forget to delete the index  
(or at least the mapping) before running this example, otherwise the new  
mapping will not get applied.

Igor

On Monday, December 17, 2012 12:41:46 AM UTC-8, Martijn v Groningen wrote:

> Hi Muhamed,
> 
> Did you install the Hunspell plugin  
> ([GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell))?  
> What kind of error did you experience?
> 
> Martijn
> 
> On 16 December 2012 20:39, muhamed alibegovic  
> \<[alibegovi...@gmail.com](mailto:alibegovi...@gmail.com) \<javascript:\>\> wrote:
> 
> > I forgot to mention that I can not make it work. Please can someone post  
> > me  
> > correct setup and usage.
> > 
> > Thanks
> > 
> > On Sunday, December 16, 2012 12:25:32 PM UTC+1, muhamed alibegovic  
> > wrote:
> > 
> > > Hello,
> > > 
> > > I'm new to ES and also search engines. I would like to use hunspell for  
> > > stemming the croatian language. This is my test setup and how I search
> > > 
> > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings":  
> > > {"analysis":  
> > > {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> > > "hr\_HR","ignoreCase": "true"}}}}}'  
> > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> > > '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > "filter"  
> > > : "hunspell\_hr" }}}}'  
> > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name":  
> > > "miki",  
> > > "description": "mi bi smo voljeli da nađemo kuće u centru grada. Jer  
> > > volimo  
> > > da imamo vrt a i da su nam blizu objekti kulture."}'  
> > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)'  
> > > -d  
> > > '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > 
> > > Thanks!
> > 
> > --
> 
> --  
> Met vriendelijke groet,
> 
> Martijn van Groningen

--

---

<div class="post-metadata">

**Author:** ![jprante](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/jprante/32/44941_2.png) [@jprante](https://discuss.elastic.co/u/jprante)\
**Post date:** [December 17, 2012, 7:03pm UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/5 "2012-12-17T19:03:27Z")

</div>

Hi,

if there is something missing with the hunspell plugin, feel free to enter  
an issue at github, with the error message (if any)

> **[GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for...](https://github.com/jprante/elasticsearch-analysis-hunspell)**
>
> Hunspell analysis for ElasticSearch. Contribute to jprante/elasticsearch-analysis-hunspell development by creating an account on GitHub.

It's quite a while since I updated it, so the chance is high it has to be  
accommodated to work with ES 0.19 or 0.20

Cheers,

Jörg

On Monday, December 17, 2012 7:14:28 PM UTC+1, Igor Motov wrote:

> Hi Muhamed,
> 
> After installing the plugin as Martijn suggested, make sure that you are  
> using the filter from the plugin in an analyzer. Here is an example:  
> [https://groups.google.com/d/topic/elasticsearch/LJVQctlocvg/discussion · GitHub](https://gist.github.com/4320493) . Don't forget to delete the index (or at  
> least the mapping) before running this example, otherwise the new mapping  
> will not get applied.
> 
> Igor
> 
> On Monday, December 17, 2012 12:41:46 AM UTC-8, Martijn v Groningen wrote:
> 
> > Hi Muhamed,
> > 
> > Did you install the Hunspell plugin  
> > ([GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell))?  
> > What kind of error did you experience?
> > 
> > Martijn
> > 
> > On 16 December 2012 20:39, muhamed alibegovic  
> > [alibegovi...@gmail.com](mailto:alibegovi...@gmail.com) wrote:
> > 
> > > I forgot to mention that I can not make it work. Please can someone  
> > > post me  
> > > correct setup and usage.
> > > 
> > > Thanks
> > > 
> > > On Sunday, December 16, 2012 12:25:32 PM UTC+1, muhamed alibegovic  
> > > wrote:
> > > 
> > > > Hello,
> > > > 
> > > > I'm new to ES and also search engines. I would like to use hunspell  
> > > > for  
> > > > stemming the croatian language. This is my test setup and how I search
> > > > 
> > > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings":  
> > > > {"analysis":  
> > > > {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> > > > "hr\_HR","ignoreCase": "true"}}}}}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> > > > '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > > "filter"  
> > > > : "hunspell\_hr" }}}}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name":  
> > > > "miki",  
> > > > "description": "mi bi smo voljeli da nađemo kuće u centru grada. Jer  
> > > > volimo  
> > > > da imamo vrt a i da su nam blizu objekti kulture."}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> > > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)'  
> > > > -d  
> > > > '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > > 
> > > > Thanks!
> > > 
> > > --
> > 
> > --  
> > Met vriendelijke groet,
> > 
> > Martijn van Groningen

--

---

<div class="post-metadata">

**Author:** ![muhamed\_alibegovic](https://avatars.discourse-cdn.com/v4/letter/m/ce7236/32.png) [@muhamed\_alibegovic](https://discuss.elastic.co/u/muhamed_alibegovic)\
**Post date:** [December 18, 2012, 7:58am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/6 "2012-12-18T07:58:32Z")

</div>

I did install it but I did't know to make it work.

On Monday, December 17, 2012 8:03:27 PM UTC+1, Jörg Prante wrote:

> Hi,
> 
> if there is something missing with the hunspell plugin, feel free to enter  
> an issue at github, with the error message (if any)
> 
> [GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell)
> 
> It's quite a while since I updated it, so the chance is high it has to be  
> accommodated to work with ES 0.19 or 0.20
> 
> Cheers,
> 
> Jörg
> 
> On Monday, December 17, 2012 7:14:28 PM UTC+1, Igor Motov wrote:
> 
> > Hi Muhamed,
> > 
> > After installing the plugin as Martijn suggested, make sure that you are  
> > using the filter from the plugin in an analyzer. Here is an example:  
> > [https://groups.google.com/d/topic/elasticsearch/LJVQctlocvg/discussion · GitHub](https://gist.github.com/4320493) . Don't forget to delete the index (or  
> > at least the mapping) before running this example, otherwise the new  
> > mapping will not get applied.
> > 
> > Igor
> > 
> > On Monday, December 17, 2012 12:41:46 AM UTC-8, Martijn v Groningen wrote:
> > 
> > > Hi Muhamed,
> > > 
> > > Did you install the Hunspell plugin  
> > > ([GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell))?  
> > > What kind of error did you experience?
> > > 
> > > Martijn
> > > 
> > > On 16 December 2012 20:39, muhamed alibegovic  
> > > [alibegovi...@gmail.com](mailto:alibegovi...@gmail.com) wrote:
> > > 
> > > > I forgot to mention that I can not make it work. Please can someone  
> > > > post me  
> > > > correct setup and usage.
> > > > 
> > > > Thanks
> > > > 
> > > > On Sunday, December 16, 2012 12:25:32 PM UTC+1, muhamed alibegovic  
> > > > wrote:
> > > > 
> > > > > Hello,
> > > > > 
> > > > > I'm new to ES and also search engines. I would like to use hunspell  
> > > > > for  
> > > > > stemming the croatian language. This is my test setup and how I  
> > > > > search
> > > > > 
> > > > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings":  
> > > > > {"analysis":  
> > > > > {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> > > > > "hr\_HR","ignoreCase": "true"}}}}}'  
> > > > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> > > > > '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > > > "filter"  
> > > > > : "hunspell\_hr" }}}}'  
> > > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name":  
> > > > > "miki",  
> > > > > "description": "mi bi smo voljeli da nađemo kuće u centru grada. Jer  
> > > > > volimo  
> > > > > da imamo vrt a i da su nam blizu objekti kulture."}'  
> > > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> > > > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)'  
> > > > > -d  
> > > > > '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > > > 
> > > > > Thanks!
> > > > 
> > > > --
> > > 
> > > --  
> > > Met vriendelijke groet,
> > > 
> > > Martijn van Groningen

--

---

<div class="post-metadata">

**Author:** ![muhamed\_alibegovic](https://avatars.discourse-cdn.com/v4/letter/m/ce7236/32.png) [@muhamed\_alibegovic](https://discuss.elastic.co/u/muhamed_alibegovic)\
**Post date:** [December 18, 2012, 8:20am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/7 "2012-12-18T08:20:18Z")

</div>

Great. Thanks for the script.

On Monday, December 17, 2012 7:14:28 PM UTC+1, Igor Motov wrote:

> Hi Muhamed,
> 
> After installing the plugin as Martijn suggested, make sure that you are  
> using the filter from the plugin in an analyzer. Here is an example:  
> [https://groups.google.com/d/topic/elasticsearch/LJVQctlocvg/discussion · GitHub](https://gist.github.com/4320493) . Don't forget to delete the index (or at  
> least the mapping) before running this example, otherwise the new mapping  
> will not get applied.
> 
> Igor
> 
> On Monday, December 17, 2012 12:41:46 AM UTC-8, Martijn v Groningen wrote:
> 
> > Hi Muhamed,
> > 
> > Did you install the Hunspell plugin  
> > ([GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell))?  
> > What kind of error did you experience?
> > 
> > Martijn
> > 
> > On 16 December 2012 20:39, muhamed alibegovic  
> > [alibegovi...@gmail.com](mailto:alibegovi...@gmail.com) wrote:
> > 
> > > I forgot to mention that I can not make it work. Please can someone  
> > > post me  
> > > correct setup and usage.
> > > 
> > > Thanks
> > > 
> > > On Sunday, December 16, 2012 12:25:32 PM UTC+1, muhamed alibegovic  
> > > wrote:
> > > 
> > > > Hello,
> > > > 
> > > > I'm new to ES and also search engines. I would like to use hunspell  
> > > > for  
> > > > stemming the croatian language. This is my test setup and how I search
> > > > 
> > > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings":  
> > > > {"analysis":  
> > > > {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> > > > "hr\_HR","ignoreCase": "true"}}}}}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> > > > '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > > "filter"  
> > > > : "hunspell\_hr" }}}}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name":  
> > > > "miki",  
> > > > "description": "mi bi smo voljeli da nađemo kuće u centru grada. Jer  
> > > > volimo  
> > > > da imamo vrt a i da su nam blizu objekti kulture."}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> > > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)'  
> > > > -d  
> > > > '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > > 
> > > > Thanks!
> > > 
> > > --
> > 
> > --  
> > Met vriendelijke groet,
> > 
> > Martijn van Groningen

--

---

<div class="post-metadata">

**Author:** ![s\_delcour](https://avatars.discourse-cdn.com/v4/letter/s/43a26b/32.png) [@s\_delcour](https://discuss.elastic.co/u/s_delcour)\
**Post date:** [July 14, 2013, 10:59pm UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/8 "2013-07-14T22:59:57Z")

</div>

Hi,

did u succeed to make it work ? I cant install it.  
I tried  
bin/plugin -install jprante/elasticsearch-analysis-hunspell  
-\> Installing jprante/elasticsearch-analysis-hunspell...  
Trying  
[https://github.com/jprante/elasticsearch-analysis-hunspell/zipball/master](https://github.com/jprante/elasticsearch-analysis-hunspell/zipball/master)...  
(assuming site plugin)  
Downloading  
.........................................................................................................................................DONE  
Plugin installation assumed to be site plugin, but contains source code,  
aborting installation...

I also tried  
bin/plugin -install jprante/elasticsearch-analysis-hunspell  
but then nothing happen

any ideas ?

Le dimanche 16 décembre 2012 12:25:32 UTC+1, muhamed alibegovic a écrit :

> Hello,
> 
> I'm new to ES and also search engines. I would like to use hunspell for  
> stemming the croatian language. This is my test setup and how I search
> 
> curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)' -d '{"settings": {"analysis":  
> {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> "hr\_HR","ignoreCase": "true"}}}}}'  
> curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)' -d  
> '{"concepts": {"properties" : {"description" : { "type" : "string",  
> "filter" : "hunspell\_hr" }}}}'  
> curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)' -d '{"name":  
> "miki", "description": "mi bi smo voljeli da nađemo kuće u centru grada.  
> Jer volimo da imamo vrt a i da su nam blizu objekti kulture."}'  
> curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)' -d  
> '{"query": {"query\_string": {"query": "description:kuća"}}'
> 
> Thanks!

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![spinscale](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/spinscale/32/25011_2.png) [@spinscale](https://discuss.elastic.co/u/spinscale)\
**Post date:** [July 15, 2013, 6:12am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/9 "2013-07-15T06:12:04Z")

</div>

Hey,

please do not reuse old threads but rather start a new one.

If you are using elasticsearch 0.90, the hunspell plugin is already part of  
the elasticsearch core and you can just use that one.

--Alex

On Mon, Jul 15, 2013 at 12:59 AM, [s.delcour@gmail.com](mailto:s.delcour@gmail.com) wrote:

> Hi,
> 
> did u succeed to make it work ? I cant install it.  
> I tried  
> bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> -\> Installing jprante/elasticsearch-analysis-hunspell...  
> Trying  
> [https://github.com/jprante/elasticsearch-analysis-hunspell/zipball/master](https://github.com/jprante/elasticsearch-analysis-hunspell/zipball/master)...  
> (assuming site plugin)  
> Downloading  
> .........................................................................................................................................DONE  
> Plugin installation assumed to be site plugin, but contains source code,  
> aborting installation...
> 
> I also tried  
> bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> but then nothing happen
> 
> any ideas ?
> 
> Le dimanche 16 décembre 2012 12:25:32 UTC+1, muhamed alibegovic a écrit :
> 
> > Hello,
> > 
> > I'm new to ES and also search engines. I would like to use hunspell for  
> > stemming the croatian language. This is my test setup and how I search
> > 
> > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)\*\*' -d '{"settings":  
> > {"analysis": {"filter": {"hunspell\_hr": {"type": "hunspell","locale":  
> > "hr\_HR","ignoreCase": "true"}}}}}'  
> > curl -XPUT '[http://localhost:9200/\*\*test50k/concepts/\_mapping](http://localhost:9200/**test50k/concepts/_mapping)[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)'  
> > -d '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > "filter" : "hunspell\_hr" }}}}'  
> > curl -XPUT '[http://localhost:9200/\*\*test50k/concepts/1](http://localhost:9200/**test50k/concepts/1)[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)'  
> > -d '{"name": "miki", "description": "mi bi smo voljeli da nađemo kuće u  
> > centru grada. Jer volimo da imamo vrt a i da su nam blizu objekti  
> > kulture."}'  
> > curl -XPUT '[http://localhost:9200/\*\*test50k/concepts/1](http://localhost:9200/**test50k/concepts/1)[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)  
> > '  
> > curl -s '[http://localhost:9200/\*\*test50k/concepts/\_search?\*\*pretty=true](http://localhost:9200/ **test50k/concepts/_search?** pretty=true)[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)'  
> > -d '{"query": {"query\_string": {"query": "description:kuća"}}'
> > 
> > Thanks!
> 
> --  
> You received this message because you are subscribed to the Google Groups  
> "elasticsearch" group.  
> To unsubscribe from this group and stop receiving emails from it, send an  
> email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Michael\_Schlenzka](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/michael_schlenzka/32/1731_2.png) [@Michael\_Schlenzka](https://discuss.elastic.co/u/Michael_Schlenzka)\
**Post date:** [November 24, 2013, 11:55am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/10 "2013-11-24T11:55:25Z")

</div>

Hello Alex,

Thx for the information - was just going down the same route and trying to  
install the hunspell plugin athough am using ES 0.90.7.

One related question - should the plugin show in the plugins dir or when  
querying installed plugins with plugin -l ?

Searched for site:www.elasticsearch.org/blog/ hunspell but could not find  
anything in the "release note" posts.

Michael

BTW great work & thank you for that, too -\>  
[http://spinscale.github.io/elasticsearch-intro-plugins/#/](http://spinscale.github.io/elasticsearch-intro-plugins/#/)

On Monday, July 15, 2013 8:12:04 AM UTC+2, Alexander Reelsen wrote:

> Hey,
> 
> please do not reuse old threads but rather start a new one.
> 
> If you are using elasticsearch 0.90, the hunspell plugin is already part  
> of the elasticsearch core and you can just use that one.
> 
> --Alex
> 
> On Mon, Jul 15, 2013 at 12:59 AM, \<[s.de...@gmail.com](mailto:s.de...@gmail.com) \<javascript:\>\> wrote:
> 
> > Hi,
> > 
> > did u succeed to make it work ? I cant install it.  
> > I tried  
> > bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> > -\> Installing jprante/elasticsearch-analysis-hunspell...  
> > Trying  
> > [https://github.com/jprante/elasticsearch-analysis-hunspell/zipball/master.](https://github.com/jprante/elasticsearch-analysis-hunspell/zipball/master.)[https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell%2Fzipball%2Fmaster.&sa=D&sntz=1&usg=AFQjCNH05dbJRcawTEdIbWqpsdGLPiCwBw](https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell%2Fzipball%2Fmaster.&sa=D&sntz=1&usg=AFQjCNH05dbJRcawTEdIbWqpsdGLPiCwBw)..  
> > (assuming site plugin)  
> > Downloading  
> > .........................................................................................................................................DONE  
> > Plugin installation assumed to be site plugin, but contains source code,  
> > aborting installation...
> > 
> > I also tried  
> > bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> > but then nothing happen
> > 
> > any ideas ?
> > 
> > Le dimanche 16 décembre 2012 12:25:32 UTC+1, muhamed alibegovic a écrit :
> > 
> > > Hello,
> > > 
> > > I'm new to ES and also search engines. I would like to use hunspell for  
> > > stemming the croatian language. This is my test setup and how I search
> > > 
> > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k&sa=D&sntz=1&usg=AFQjCNFHgBDWx-sMqv4hyGeLP6O2zZxivQ](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k&sa=D&sntz=1&usg=AFQjCNFHgBDWx-sMqv4hyGeLP6O2zZxivQ)'  
> > > -d '{"settings": {"analysis": {"filter": {"hunspell\_hr": {"type":  
> > > "hunspell","locale": "hr\_HR","ignoreCase": "true"}}}}}'  
> > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F\_mapping&sa=D&sntz=1&usg=AFQjCNGP2n\_vcku1IiUrNW9loSUizR6fXw](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F_mapping&sa=D&sntz=1&usg=AFQjCNGP2n_vcku1IiUrNW9loSUizR6fXw)'  
> > > -d '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > "filter" : "hunspell\_hr" }}}}'  
> > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g)'  
> > > -d '{"name": "miki", "description": "mi bi smo voljeli da nađemo kuće u  
> > > centru grada. Jer volimo da imamo vrt a i da su nam blizu objekti  
> > > kulture."}'  
> > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g)  
> > > '  
> > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F\_search%3Fpretty%3Dtrue&sa=D&sntz=1&usg=AFQjCNEyVtU9OyWhH8MLue-qt2UfQCHVhA](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F_search%3Fpretty%3Dtrue&sa=D&sntz=1&usg=AFQjCNEyVtU9OyWhH8MLue-qt2UfQCHVhA)'  
> > > -d '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > 
> > > Thanks!
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearc...@googlegroups.com](mailto:elasticsearc...@googlegroups.com) \<javascript:\>.  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![spinscale](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/spinscale/32/25011_2.png) [@spinscale](https://discuss.elastic.co/u/spinscale)\
**Post date:** [November 24, 2013, 1:13pm UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/11 "2013-11-24T13:13:32Z")

</div>

Hey,

please do not reuse old threads but rather start a new one. 🙂

As hunspell is now part of the core, it will never be shown as a plugin  
anywhere. It is part of the core as of 0.90.0 - also the plugin seems only  
to support up to elasticsearch 0.18.0, judging from

> **[GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for...](https://github.com/jprante/elasticsearch-analysis-hunspell)**
>
> Hunspell analysis for ElasticSearch. Contribute to jprante/elasticsearch-analysis-hunspell development by creating an account on GitHub.

--Alex

On Sun, Nov 24, 2013 at 12:55 PM, Michael Schlenzka  
[michael@schlenzka.com](mailto:michael@schlenzka.com)wrote:

> Hello Alex,
> 
> Thx for the information - was just going down the same route and trying to  
> install the hunspell plugin athough am using ES 0.90.7.
> 
> One related question - should the plugin show in the plugins dir or when  
> querying installed plugins with plugin -l ?
> 
> Searched for site:www.elasticsearch.org/blog/ hunspell but could not  
> find anything in the "release note" posts.
> 
> Michael
> 
> BTW great work & thank you for that, too -\>  
> [Elasticsearch - A look under the hood](http://spinscale.github.io/elasticsearch-intro-plugins/#/)
> 
> On Monday, July 15, 2013 8:12:04 AM UTC+2, Alexander Reelsen wrote:
> 
> > Hey,
> > 
> > please do not reuse old threads but rather start a new one.
> > 
> > If you are using elasticsearch 0.90, the hunspell plugin is already part  
> > of the elasticsearch core and you can just use that one.
> > 
> > --Alex
> > 
> > On Mon, Jul 15, 2013 at 12:59 AM, [s.de...@gmail.com](mailto:s.de...@gmail.com) wrote:
> > 
> > > Hi,
> > > 
> > > did u succeed to make it work ? I cant install it.  
> > > I tried  
> > > bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> > > -\> Installing jprante/elasticsearch-analysis-hunspell...  
> > > Trying [https://github.com/jprante/elasticsearch-analysis-](https://github.com/jprante/elasticsearch-analysis-)  
> > > hunspell/zipball/master.[https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell%2Fzipball%2Fmaster.&sa=D&sntz=1&usg=AFQjCNH05dbJRcawTEdIbWqpsdGLPiCwBw](https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell%2Fzipball%2Fmaster.&sa=D&sntz=1&usg=AFQjCNH05dbJRcawTEdIbWqpsdGLPiCwBw)..  
> > > (assuming site plugin)  
> > > Downloading ............................................................  
> > > ............................................................  
> > > .................DONE  
> > > Plugin installation assumed to be site plugin, but contains source code,  
> > > aborting installation...
> > > 
> > > I also tried  
> > > bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> > > but then nothing happen
> > > 
> > > any ideas ?
> > > 
> > > Le dimanche 16 décembre 2012 12:25:32 UTC+1, muhamed alibegovic a écrit :
> > > 
> > > > Hello,
> > > > 
> > > > I'm new to ES and also search engines. I would like to use hunspell for  
> > > > stemming the croatian language. This is my test setup and how I search
> > > > 
> > > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k&sa=D&sntz=1&usg=AFQjCNFHgBDWx-sMqv4hyGeLP6O2zZxivQ](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k&sa=D&sntz=1&usg=AFQjCNFHgBDWx-sMqv4hyGeLP6O2zZxivQ)'  
> > > > -d '{"settings": {"analysis": {"filter": {"hunspell\_hr": {"type":  
> > > > "hunspell","locale": "hr\_HR","ignoreCase": "true"}}}}}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F\_mapping&sa=D&sntz=1&usg=AFQjCNGP2n\_vcku1IiUrNW9loSUizR6fXw](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F_mapping&sa=D&sntz=1&usg=AFQjCNGP2n_vcku1IiUrNW9loSUizR6fXw)'  
> > > > -d '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > > "filter" : "hunspell\_hr" }}}}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g)'  
> > > > -d '{"name": "miki", "description": "mi bi smo voljeli da nađemo kuće u  
> > > > centru grada. Jer volimo da imamo vrt a i da su nam blizu objekti  
> > > > kulture."}'  
> > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g)  
> > > > '  
> > > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F\_search%3Fpretty%3Dtrue&sa=D&sntz=1&usg=AFQjCNEyVtU9OyWhH8MLue-qt2UfQCHVhA](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F_search%3Fpretty%3Dtrue&sa=D&sntz=1&usg=AFQjCNEyVtU9OyWhH8MLue-qt2UfQCHVhA)'  
> > > > -d '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > > 
> > > > Thanks!
> > > 
> > > --  
> > > You received this message because you are subscribed to the Google  
> > > Groups "elasticsearch" group.  
> > > To unsubscribe from this group and stop receiving emails from it, send  
> > > an email to [elasticsearc...@googlegroups.com](mailto:elasticsearc...@googlegroups.com).
> > > 
> > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > 
> > --  
> > You received this message because you are subscribed to the Google Groups  
> > "elasticsearch" group.  
> > To unsubscribe from this group and stop receiving emails from it, send an  
> > email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
> > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![Michael\_Schlenzka](https://sea2.discourse-cdn.com/elastic/user_avatar/discuss.elastic.co/michael_schlenzka/32/1731_2.png) [@Michael\_Schlenzka](https://discuss.elastic.co/u/Michael_Schlenzka)\
**Post date:** [November 24, 2013, 3:51pm UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/12 "2013-11-24T15:51:03Z")

</div>

Sorry about the reuse 😕

Thank you for the answer and clarification - was not looking in the right  
place before - have meanwhile found the same answer on github (  
[Analysis: Integration with Hunspell · Issue #646 · elastic/elasticsearch · GitHub](https://github.com/elasticsearch/elasticsearch/issues/646) ), wanted to post  
later, but you were faster.

Michael

On Sunday, November 24, 2013 2:13:32 PM UTC+1, Alexander Reelsen wrote:

> Hey,
> 
> please do not reuse old threads but rather start a new one. 🙂
> 
> As hunspell is now part of the core, it will never be shown as a plugin  
> anywhere. It is part of the core as of 0.90.0 - also the plugin seems only  
> to support up to elasticsearch 0.18.0, judging from  
> [GitHub - jprante/elasticsearch-analysis-hunspell: Hunspell analysis for ElasticSearch](https://github.com/jprante/elasticsearch-analysis-hunspell)[https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell&sa=D&sntz=1&usg=AFQjCNGr4pIKPufE7FoNGQPrZF91J0\_t9g](https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell&sa=D&sntz=1&usg=AFQjCNGr4pIKPufE7FoNGQPrZF91J0_t9g)
> 
> --Alex
> 
> On Sun, Nov 24, 2013 at 12:55 PM, Michael Schlenzka \<[mic...@schlenzka.com](mailto:mic...@schlenzka.com)\<javascript:\>
> 
> > wrote:
> 
> > Hello Alex,
> > 
> > Thx for the information - was just going down the same route and trying  
> > to install the hunspell plugin athough am using ES 0.90.7.
> > 
> > One related question - should the plugin show in the plugins dir or when  
> > querying installed plugins with plugin -l ?
> > 
> > Searched for site:www.elasticsearch.org/blog/[http://www.google.com/url?q=http%3A%2F%2Fwww.elasticsearch.org%2Fblog%2F&sa=D&sntz=1&usg=AFQjCNEyoA9DUiPvK1Re1gmvdXKkHbzDDQ](http://www.google.com/url?q=http%3A%2F%2Fwww.elasticsearch.org%2Fblog%2F&sa=D&sntz=1&usg=AFQjCNEyoA9DUiPvK1Re1gmvdXKkHbzDDQ)hunspell but could not find anything in the "release note" posts.
> > 
> > Michael
> > 
> > BTW great work & thank you for that, too -\>  
> > [Elasticsearch - A look under the hood](http://spinscale.github.io/elasticsearch-intro-plugins/#/)[http://www.google.com/url?q=http%3A%2F%2Fspinscale.github.io%2Felasticsearch-intro-plugins%2F%23%2F&sa=D&sntz=1&usg=AFQjCNFRi4P6PX7AB5gaIa7YEbammJmCqA](http://www.google.com/url?q=http%3A%2F%2Fspinscale.github.io%2Felasticsearch-intro-plugins%2F%23%2F&sa=D&sntz=1&usg=AFQjCNFRi4P6PX7AB5gaIa7YEbammJmCqA)
> > 
> > On Monday, July 15, 2013 8:12:04 AM UTC+2, Alexander Reelsen wrote:
> > 
> > > Hey,
> > > 
> > > please do not reuse old threads but rather start a new one.
> > > 
> > > If you are using elasticsearch 0.90, the hunspell plugin is already part  
> > > of the elasticsearch core and you can just use that one.
> > > 
> > > --Alex
> > > 
> > > On Mon, Jul 15, 2013 at 12:59 AM, [s.de...@gmail.com](mailto:s.de...@gmail.com) wrote:
> > > 
> > > > Hi,
> > > > 
> > > > did u succeed to make it work ? I cant install it.  
> > > > I tried  
> > > > bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> > > > -\> Installing jprante/elasticsearch-analysis-hunspell...  
> > > > Trying [https://github.com/jprante/elasticsearch-analysis-](https://github.com/jprante/elasticsearch-analysis-)  
> > > > hunspell/zipball/master.[https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell%2Fzipball%2Fmaster.&sa=D&sntz=1&usg=AFQjCNH05dbJRcawTEdIbWqpsdGLPiCwBw](https://www.google.com/url?q=https%3A%2F%2Fgithub.com%2Fjprante%2Felasticsearch-analysis-hunspell%2Fzipball%2Fmaster.&sa=D&sntz=1&usg=AFQjCNH05dbJRcawTEdIbWqpsdGLPiCwBw)..  
> > > > (assuming site plugin)  
> > > > Downloading ..............................  
> > > > ............................................................  
> > > > ...............................................DONE  
> > > > Plugin installation assumed to be site plugin, but contains source  
> > > > code, aborting installation...
> > > > 
> > > > I also tried  
> > > > bin/plugin -install jprante/elasticsearch-analysis-hunspell  
> > > > but then nothing happen
> > > > 
> > > > any ideas ?
> > > > 
> > > > Le dimanche 16 décembre 2012 12:25:32 UTC+1, muhamed alibegovic a  
> > > > écrit :
> > > > 
> > > > > Hello,
> > > > > 
> > > > > I'm new to ES and also search engines. I would like to use hunspell  
> > > > > for stemming the croatian language. This is my test setup and how I search
> > > > > 
> > > > > curl -XPUT '[http://localhost:9200/test50k](http://localhost:9200/test50k)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k&sa=D&sntz=1&usg=AFQjCNFHgBDWx-sMqv4hyGeLP6O2zZxivQ](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k&sa=D&sntz=1&usg=AFQjCNFHgBDWx-sMqv4hyGeLP6O2zZxivQ)'  
> > > > > -d '{"settings": {"analysis": {"filter": {"hunspell\_hr": {"type":  
> > > > > "hunspell","locale": "hr\_HR","ignoreCase": "true"}}}}}'  
> > > > > curl -XPUT '[http://localhost:9200/test50k/concepts/\_mapping](http://localhost:9200/test50k/concepts/_mapping)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F\_mapping&sa=D&sntz=1&usg=AFQjCNGP2n\_vcku1IiUrNW9loSUizR6fXw](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F_mapping&sa=D&sntz=1&usg=AFQjCNGP2n_vcku1IiUrNW9loSUizR6fXw)'  
> > > > > -d '{"concepts": {"properties" : {"description" : { "type" : "string",  
> > > > > "filter" : "hunspell\_hr" }}}}'  
> > > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g)'  
> > > > > -d '{"name": "miki", "description": "mi bi smo voljeli da nađemo kuće u  
> > > > > centru grada. Jer volimo da imamo vrt a i da su nam blizu objekti  
> > > > > kulture."}'  
> > > > > curl -XPUT '[http://localhost:9200/test50k/concepts/1](http://localhost:9200/test50k/concepts/1)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F1&sa=D&sntz=1&usg=AFQjCNF5Wq-xLxioYJ-L0hHWfaCxBV0X9g)  
> > > > > '  
> > > > > curl -s '[http://localhost:9200/test50k/concepts/\_search?pretty=true](http://localhost:9200/test50k/concepts/_search?pretty=true)[http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F\_search%3Fpretty%3Dtrue&sa=D&sntz=1&usg=AFQjCNEyVtU9OyWhH8MLue-qt2UfQCHVhA](http://www.google.com/url?q=http%3A%2F%2Flocalhost%3A9200%2Ftest50k%2Fconcepts%2F_search%3Fpretty%3Dtrue&sa=D&sntz=1&usg=AFQjCNEyVtU9OyWhH8MLue-qt2UfQCHVhA)'  
> > > > > -d '{"query": {"query\_string": {"query": "description:kuća"}}'
> > > > > 
> > > > > Thanks!
> > > > 
> > > > --  
> > > > You received this message because you are subscribed to the Google  
> > > > Groups "elasticsearch" group.  
> > > > To unsubscribe from this group and stop receiving emails from it, send  
> > > > an email to [elasticsearc...@googlegroups.com](mailto:elasticsearc...@googlegroups.com).
> > > > 
> > > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).
> > > 
> > > --  
> > > You received this message because you are subscribed to the Google Groups  
> > > "elasticsearch" group.  
> > > To unsubscribe from this group and stop receiving emails from it, send an  
> > > email to [elasticsearc...@googlegroups.com](mailto:elasticsearc...@googlegroups.com) \<javascript:\>.  
> > > For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![system](https://us1.discourse-cdn.com/elastic/original/3X/1/a/1ac57faf039f6b580b3f104ef42a2a89e41014de.png) [@system](https://discuss.elastic.co/u/system)\
**Post date:** [July 6, 2017, 2:05am UTC](https://discuss.elastic.co/t/cannot-make-hunspell-to-work/10082/13 "2017-07-06T02:05:07Z")

</div>


